@@ -6,7 +6,9 @@ from inline_snapshot import outsource
 from inline_snapshot import snapshot
 from inline_snapshot._find_external import ensure_import
 from inline_snapshot.extra import raises
+from inline_snapshot.testing._example import Example
 from tests.utils import config
+from tests.utils import storage  # noqa
 
 from .utils import apply_changes
 
@@ -100,7 +102,7 @@ def test_something():
 | -    assert 2 == snapshot(1+1)                                               |
 | +    assert 2 == snapshot(2)                                                 |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=update
+These changes will be applied, because you used update
 """
     )
 
@@ -127,7 +129,7 @@ def test_a():
         """\
 >       assert outsource("test2") == snapshot(
 E       AssertionError: assert 'test2' == 'test'
-E         ⏎
+E         \n\
 E         - test
 E         + test2
 E         ?     +
@@ -157,7 +159,7 @@ def test_a():
         """\
 >       assert outsource(b"test2") == snapshot(
 E       AssertionError: assert b'test2' == b'test'
-E         ⏎
+E         \n\
 E         Use -v to get more diff
 """
     )
@@ -337,7 +339,7 @@ test_something()
 
     result = project.run("--inline-snapshot=create")
 
-    result.assert_outcomes(passed=1)
+    result.assert_outcomes(errors=1, passed=1)
 
     assert project.source == snapshot(
         """\
@@ -443,3 +445,19 @@ def test_something():
             "8dc140e6fe831481a2005ae152ffe32a9974aa92a260dfbac780d6a87154bb0b-new.txt",
         ]
     )
+
+
+def test_persist_twice():
+    Example(
+        """\
+from inline_snapshot import snapshot,outsource
+
+def test_a():
+    assert outsource("testabc") == snapshot()
+    assert 1+1==snapshot()
+"""
+    ).run_pytest(["--inline-snapshot=create"], returncode=1).code_change(
+        "snapshot(2)", "snapshot()"
+    ).run_pytest(
+        ["--inline-snapshot=create"], returncode=1
+    )
