@@ -19,7 +19,7 @@ def test_a():
 """
     )
 
-    result = project.run()
+    result = project.run("--inline-snapshot=short-report")
 
     result.assert_outcomes(errors=1, passed=1)
 
@@ -32,7 +32,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
 
     result = project.run("--inline-snapshot=create")
 
-    result.assert_outcomes(passed=1)
+    result.assert_outcomes(passed=1, errors=1)
 
     assert result.report == snapshot(
         """\
@@ -46,7 +46,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
 | -    assert 5==snapshot()                                                    |
 | +    assert 5==snapshot(5)                                                   |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=create
+These changes will be applied, because you used create
 """
     )
 
@@ -66,7 +66,7 @@ def test_a():
 """
     )
 
-    result = project.run()
+    result = project.run("--inline-snapshot=short-report")
 
     result.assert_outcomes(failed=1, errors=1)
 
@@ -79,7 +79,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
 
     result = project.run("--inline-snapshot=fix")
 
-    result.assert_outcomes(passed=1)
+    result.assert_outcomes(passed=1, errors=1)
 
     assert result.report == snapshot(
         """\
@@ -93,7 +93,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
 | -    assert 5==snapshot(4)                                                   |
 | +    assert 5==snapshot(5)                                                   |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=fix
+These changes will be applied, because you used fix
 """
     )
 
@@ -113,7 +113,7 @@ def test_a():
 """
     )
 
-    result = project.run()
+    result = project.run("--inline-snapshot=short-report")
 
     result.assert_outcomes(passed=1)
 
@@ -142,7 +142,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
 | -    assert "5" == snapshot('''5''')                                         |
 | +    assert "5" == snapshot("5")                                             |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=update
+These changes will be applied, because you used update
 """
     )
 
@@ -162,7 +162,7 @@ def test_a():
 """
     )
 
-    result = project.run()
+    result = project.run("--inline-snapshot=short-report")
 
     result.assert_outcomes(passed=1)
 
@@ -187,7 +187,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
 | -    assert 5 in snapshot([4,5])                                             |
 | +    assert 5 in snapshot([5])                                               |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=trim
+These changes will be applied, because you used trim
 """
     )
 
@@ -209,7 +209,7 @@ def test_a():
 """
     )
 
-    result = project.run()
+    result = project.run("--inline-snapshot=short-report")
 
     result.assert_outcomes(failed=1, errors=1)
 
@@ -246,7 +246,7 @@ You can also use --inline-snapshot=review to approve the changes interactively
 | -    assert 5 == snapshot(4)                                                 |
 | +    assert 5 == snapshot(5)                                                 |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=fix
+These changes will be applied, because you used fix
 -------------------------------- Trim snapshots --------------------------------
 +-------------------------------- test_file.py --------------------------------+
 | @@ -5,5 +5,5 @@                                                              |
@@ -258,7 +258,7 @@ These changes will be applied, because you used --inline-snapshot=fix
 | +    assert 5 <= snapshot(5)                                                 |
 |      assert 5 == snapshot(5)                                                 |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=trim
+These changes will be applied, because you used trim
 """
     )
 
@@ -302,6 +302,13 @@ def test_a():
 """
     )
 
+    project.pyproject(
+        """
+[tool.inline-snapshot]
+show-updates=true
+"""
+    )
+
     result = project.run("--inline-snapshot=trim,report")
 
     assert result.report == snapshot(
@@ -330,7 +337,7 @@ Use --inline-snapshot=fix to apply them, or use the interactive mode with
 | +    assert 5 <= snapshot(5)                                                 |
 |      assert 5 == snapshot(4)                                                 |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=trim
+These changes will be applied, because you used trim
 ------------------------------- Update snapshots -------------------------------
 +-------------------------------- test_file.py --------------------------------+
 | @@ -4,6 +4,6 @@                                                              |
@@ -430,7 +437,7 @@ def test_a():
         """\
 >       assert "a"==snapshot("b")
 E       AssertionError: assert 'a' == 'b'
-E         ⏎
+E         \n\
 E         - b
 E         + a
 """
@@ -448,7 +455,7 @@ def test_a():
         """\
 >       assert snapshot("b")=="a"
 E       AssertionError: assert 'b' == 'a'
-E         ⏎
+E         \n\
 E         - a
 E         + b
 """
@@ -537,7 +544,7 @@ def test_something():
 | -    assert 2 == snapshot(1)                                                 |
 | +    assert 2 == snapshot(2)                                                 |
 +------------------------------------------------------------------------------+
-do you want to fix these snapshots? [y/n] (n):
+Do you want to fix these snapshots? [y/n] (n):
 """
     )
 
@@ -561,21 +568,40 @@ def test_sub_snapshot():
 
     project.term_columns = 160
 
-    result = project.run()
+    result = project.run("--inline-snapshot=short-report")
 
     assert result.ret == 1
 
-    assert result.errors == snapshot(
-        """\
+    if "insider" in result.errors:  # pragma: no cover
+        assert result.errors == snapshot(
+            """\
 ============================================================================ ERRORS ============================================================================
 ____________________________________________________________ ERROR at teardown of test_sub_snapshot ____________________________________________________________
 your snapshot is missing one value.
-======================================================================= inline snapshot ========================================================================
+============================================================== inline snapshot (insider version) ===============================================================
 Error: one snapshot is missing a value (--inline-snapshot=create)
 You can also use --inline-snapshot=review to approve the changes interactively
 =================================================================== short test summary info ====================================================================
 ERROR test_file.py::test_sub_snapshot - Failed: your snapshot is missing one value.
 ================================================================== 1 passed, 1 error in <time> ==================================================================
+"""
+        )
+    else:
+        assert result.errors == snapshot(
+            """\
+============================================================================ ERRORS ============================================================================
+____________________________________________________________ ERROR at teardown of test_sub_snapshot ____________________________________________________________
+your snapshot is missing one value.
+If you just created this value with --snapshot=create, the value is now created and you can ignore this message.
+=================================================================== short test summary info ====================================================================
+ERROR test_file.py::test_sub_snapshot - Failed: your snapshot is missing one value.
+================================================================== 1 passed, 1 error in <time> ==================================================================
+"""
+        )
+    assert result.report == snapshot(
+        """\
+Error: one snapshot is missing a value (--inline-snapshot=create)
+You can also use --inline-snapshot=review to approve the changes interactively
 """
     )
 
@@ -603,7 +629,7 @@ def test_sub_snapshot():
 """
     )
 
-    assert result.ret == 0
+    assert result.ret == 1
 
 
 def test_diff_multiple_files():
@@ -657,7 +683,7 @@ def test_a():
 | -    assert 1==snapshot()                                                    |
 | +    assert 1==snapshot(1)                                                   |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=create
+These changes will be applied, because you used create
 -------------------------------- Fix snapshots ---------------------------------
 +--------------------------------- test_a.py ----------------------------------+
 | @@ -2,5 +2,5 @@                                                              |
@@ -668,9 +694,10 @@ These changes will be applied, because you used --inline-snapshot=create
 | -    assert 1==snapshot(2)                                                   |
 | +    assert 1==snapshot(1)                                                   |
 +------------------------------------------------------------------------------+
-These changes will be applied, because you used --inline-snapshot=fix\
+These changes will be applied, because you used fix\
 """
         ),
+        returncode=1,
     )
 
 
@@ -786,7 +813,7 @@ def test_outsource():
     )
 
     result = project.run("--inline-snapshot=create")
-    assert result.ret == 0
+    assert result.ret == 1
     assert project.source == snapshot(
         """\
 from inline_snapshot import outsource, snapshot
@@ -798,7 +825,7 @@ def test_outsource():
 """
     )
 
-    project.run("--inline-snapshot=fix")
+    result = project.run("--inline-snapshot=fix")
     assert result.ret == 0
 
     assert project.storage(storage_dir) == snapshot(
@@ -806,7 +833,7 @@ def test_outsource():
     )
 
 
-def test_find_pyproject_in_parent_directories(tmp_path):
+def test_find_pyproject_in_parent_directories():
 
     Example(
         {
@@ -834,4 +861,88 @@ def test_something():
 """
             }
         ),
+        returncode=1,
+    )
+
+
+@pytest.mark.xfail(
+    not is_pytest_compatible(), reason="this works only for cpython >=3.11"
+)
+def test_default_report():
+
+    Example(
+        """\
+import pytest
+from inline_snapshot import snapshot
+
+def test_a():
+    assert 1==snapshot(5)
+"""
+    ).run_pytest(
+        report=snapshot(
+            """\
+-------------------------------- Fix snapshots ---------------------------------
++----------------------------- test_something.py ------------------------------+
+| @@ -2,4 +2,4 @@                                                              |
+|                                                                              |
+|  from inline_snapshot import snapshot                                        |
+|                                                                              |
+|  def test_a():                                                               |
+| -    assert 1==snapshot(5)                                                   |
+| +    assert 1==snapshot(1)                                                   |
++------------------------------------------------------------------------------+
+These changes are not applied.
+Use --inline-snapshot=fix to apply them, or use the interactive mode with
+--inline-snapshot=review\
+"""
+        ),
+        returncode=snapshot(1),
+        stderr=snapshot(""),
+        changed_files=snapshot({}),
+    )
+
+
+@pytest.mark.xfail(
+    not is_pytest_compatible(), reason="this works only for cpython >=3.11"
+)
+def test_default_review():
+
+    Example(
+        """\
+import pytest
+from inline_snapshot import snapshot
+
+def test_a():
+    assert 1==snapshot(5)
+"""
+    ).run_pytest(
+        report=snapshot(
+            """\
+-------------------------------- Fix snapshots ---------------------------------
++----------------------------- test_something.py ------------------------------+
+| @@ -2,4 +2,4 @@                                                              |
+|                                                                              |
+|  from inline_snapshot import snapshot                                        |
+|                                                                              |
+|  def test_a():                                                               |
+| -    assert 1==snapshot(5)                                                   |
+| +    assert 1==snapshot(1)                                                   |
++------------------------------------------------------------------------------+
+Do you want to fix these snapshots? [y/n] (n):\
+"""
+        ),
+        returncode=snapshot(1),
+        stderr=snapshot(""),
+        changed_files=snapshot(
+            {
+                "test_something.py": """\
+import pytest
+from inline_snapshot import snapshot
+
+def test_a():
+    assert 1==snapshot(1)
+"""
+            }
+        ),
+        stdin=b"y\n",
     )
